pub fn render_markdown(snapshot: &ProcessSnapshot) -> StringExpand description
Render a process snapshot as a Markdown report (includes capture time and peek version).
pub fn render_markdown(snapshot: &ProcessSnapshot) -> StringRender a process snapshot as a Markdown report (includes capture time and peek version).